@@ -11,7 +11,7 @@ use IO::Select;
 use POSIX;
 use Symbol;
 
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 # --- globals
 
@@ -75,6 +75,8 @@ sub unlink_pidfile {
 
 sub kill_running {
     my ($self) = @_;
+    die "You did not daemonize, so you cannot kill_running()"
+        unless $self->{daemonized};
     for ({sig=>"TERM", delay=>1},
          {sig=>"TERM", delay=>3},
          {sig=>"KILL"},
@@ -166,7 +168,6 @@ sub child_sig_handlers {
 sub init {
     my ($self) = @_;
 
-    $self->{pid_path} or die "BUG: Please specify pid_path";
     #$self->{scoreboard_path} or die "BUG: Please specify scoreboard_path";
     if ($self->{require_root}) {
         $> and die "Permission denied, daemon must be run as root\n";
@@ -626,7 +627,7 @@ SHARYANTO::Proc::Daemon::Prefork - Create preforking, autoreloading daemon
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =for Pod::Coverage .
 
@@ -646,7 +647,7 @@ If true, bails out if not running as root.
 
 =item * access_log_path => STR (required if daemonize=1)
 
-=item * pid_path* => STR
+=item * pid_path => STR (required if daemonize=1)
 
 =item * scoreboard_path => STR (default none)
 
